#
# spec file for package mate-calc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.28

Name:           mate-calc
Version:        1.28.0
Release:        1.6
Summary:        MATE Desktop calculator application
License:        GPL-2.0-or-later
URL:            https://mate-desktop.org/
Group:          system/GUI/Other
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  mate-common >= %{_version}
BuildRequires:  mpc-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mpfr)
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
mate-calc is a calculator application that was part of the
OpenWindows Deskset of the Solaris 8 operating system.
It incorporates multiple precision arithmetic packages based on the
work of Professor Richard Brent.

%lang_package

%prep
%setup -q

%build
NOCONFIGURE=1 mate-autogen
%configure
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file %{name}
%fdupes %{buildroot}%{_datadir}/

%files
%license COPYING
%doc NEWS README.md
%{_bindir}/mate-calc
%{_bindir}/mate-calc-cmd
%{_bindir}/mate-calculator
%{_datadir}/applications/%{name}.desktop
%{_datadir}/glib-2.0/schemas/*.xml
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/help/*/%{name}/
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}-cmd.1%{?ext_man}

%files lang -f %{name}.lang
%exclude %{_datadir}/help/*

%changelog
* Wed Mar 27 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Translations update
  * Fix implicit function declarations with libxml2 2.12
  * tx: fix warning in Japanese translations
* Fri Aug 13 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Translations update
  * Add build support for meson
  * integrate unittest into test-mp-equation
  * Fix declaration/definition mismatches
  * update copyright to 2021
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.24.2
  * Translations update
  * mp-serializer: fix memory leaks reported by valgrind
* Sun Aug 16 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.1:
  * Fixes incorrect parenthesis handling.
  * build: Silent build warnings for distcheck.
  * Use default MATE_COMPILE_WARNINGS level.
  * math-buttons: Add space character after inverse trigonometric
    functions.
  * mate-calc.desktop: Do not collect the translation for Icon.
  * Read authors (updated) from mate-calc.about.
  * Update translations.
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0:
  * Fix typo: "Avogadro" instead of "Avogrado".
  * Fix precedence of functions i.e. the result of -ln(1) and add
    according tests.
  * Fix typo in keywords in desktop file.
  * mate-calc.desktop.in: Add missing Keywords.
  * Do not remove org.mate.calc.gschema.xml on make distclean.
  * The function "mp_mask" is never used.
  * Set the required version for gettext (0.19.8).
  * parserfunc: Return NULL on NOT operation overflow.
  * Update translations.
- Drop support for old openSUSE versions.
* Wed Jul 17 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.0:
  * Update translations.
  * Migrate from intltools into gettext
  * mp-serializer: fix scientific presentation of complex numbers
  * Avoid deprecated 'gtk_widget_get_style' and 'gtk_widget_modify_font'
  * Fix FSF address
  * test-mp-equation: add tests for physical constants
  * mp-equation: update values from physical constants to match
    with tooltip values in math-buttons.c
  * Add unit tooltips to physical constants
  * dont focus on click
  * mp-equation: add pre-defined physical constants
  * buttons-ui: add destructive-action style to 'clear' button
  * buttons-ui: add style class "suggested-action" to result button
  * Use gresources for UI files
  * Unit tests: pi constant, ln (e^iπ)
  * currency-manager: Update name_map in load_imf_rates
  * math-buttons: Fix cppcheck warning: Identical inner 'return'
  * math-buttons: avoid shifting signed 64-bit value by 63 bits
  * Add support for "pi" in addition to "π"
  * i18n about dialog
- remove patch:
  * mate-calc-gtk-3.20.patch: we don't support gtk3.20 anymore
- build require gtk >= 3.22, glib >= 2.50 and gio >= 2.50
- don't install *.ui files anymore as they were moved to src/
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * currency-manager: Update name_map in load_imf_rates.
  * Display small numbers in scientific notation.
  * mp: Fix calculate result ln(e^(i*π)).
  * mate-calc: Fix memory leak.
  * Update translations.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * UI: Avoid deprecated GtkButton:use-stock.
  * UI: Drop all deprecated elements.
  * Replace deprecated gtk_menu_popup.
  * Avoid deprecated gtk_image_menu_item_new_from_stock.
  * Increase accuracy range to 15.
  * math-display: Avoid deprecated 'gtk_widget_modify_bg'
  * Avoid deprecated g_type_class_add_private.
  * Remove duplicated assignment.
  * Disable deprecation warnings for distcheck.
  * math-window: Fix memory leak.
  * math-display.c: Avoid deprecated gtk_widget_ensure_style.
  * ui files: Add missing icons in titles to dialogues.
  * buttons-programming.ui: Fix buttons.
- Rebase mate-calc-gtk-3.20.patch.
* Sat Dec 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.3:
  * data: Update appdata directory.
  * Use make functions for HELP_LINGUAS.
  * Write equation using MathML.
  * Fix application name.
  * Fix repeated words.
  * Copy equation as ASCII text.
  * Update translations.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * Update translations.
* Wed Apr 11 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * math-preferences: Add window icon to the Preferences dialogue.
  * Init gtk before math_equation_new.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * Add an icon image on the close button in the Preferences
    dialogue.
  * Avoid deprecated GtkStock.
  * math-window: Don't use deprecated gtk_show_uri().
  * Add the missing window icon to the About dialogue.
  * Update translations.
- Add mate-calc-gtk-3.20.patch: Restore GLib 2.48 and
  GTK+ 3.20 support.
* Wed Oct 25 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0 (changes since 1.8.0):
  * Move to GTK+3 (>= 3.14), GTK+2 code, and --with-gtk build
    option.
  * Add an AppStream file.
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Thu Feb 20 2014 p.drouand@gmail.com
- Update to version 1.7.90
  + make numpad period work without numlock on
  + enable yelp documentation
- Replace mate-doc-utils requirement with yelp-tools; upstream dopped
  mate-doc-utils and now use yelp-tools to build help
- Remove useless xz requirement
* Fri Sep 20 2013 cfarrell@suse.com
- license update: GPL-2.0+
  No indication of GPL-2.0 only licenses
* Wed Apr  3 2013 p.drouand@gmail.com
- Update to version 1.6.0
  + update configure.ac
  + update translations
- Add a mate-calc Recommends tag
* Sat Mar 23 2013 p.drouand@gmail.com
- Update to version 1.5.2
  + AC_CONFIG_HEADERS to please automake 1.13
  + add support glib 2.30
- Remove mate-calc-1.5.1-support_glib_2.30.patch; merged on upstream
  release
* Wed Dec  5 2012 nmo.marques@gmail.com
- Add mate-calc-1.5.1-support_glib_2.30.patch: support glib 2.30,
  fixes build on 12.1, cherry pick from upstream
* Mon Nov 26 2012 nmo.marques@gmail.com
- Update to version 1.5.1
  + fixed broken undo and clear buttons for financial and
    programming mode
  + fixed gsettings
  + Added inverse trigonometry functions
  + Menu fix and cleanups (GTK)
- Remove files entries for help, the files are no longer installed
* Mon Nov 19 2012 nmarques@mate-desktop.org
- Update BuildRequires: use libxml2-python to fix 12.1 build
* Sun Nov  4 2012 nmarques@mate-desktop.org
- Initial package from release 1.5.0
